import pathlib

import click
import seisbench

from .__about__ import __version__
from .gpd import GPDModelRunner
from .model_runner import list_pretrained_models


@click.group()
def cli():
    pass


@cli.command
def version():
    """Prints version"""
    print(f"SeisBench v{seisbench.__version__}")
    print(f"gpd_tool v{__version__}")


@cli.command
def citation():
    """Prints citation of the model"""
    m = GPDModelRunner()
    print(m.citation())


@cli.command
def list_pretrained():
    """Show pretrained model names"""
    print(", ".join(list_pretrained_models(GPDModelRunner)))


@cli.command
@click.option(
    "-w",
    "--weights",
    default="original",
    type=str,
    show_default=True,
    help=f"for possible options see output of 'list-pretrained'",
)
@click.option(
    "-o",
    "--output",
    default=pathlib.Path("."),
    type=click.Path(dir_okay=True, path_type=pathlib.Path),
    show_default=True,
    help="directory to store results",
)
@click.option(
    "-s",
    "--stride",
    default=10,
    type=int,
    show_default=True,
    help="stride in samples for point prediction models",
)
@click.option(
    "-tp",
    "--threshold-p",
    default=0.75,
    type=float,
    show_default=True,
    help="detection threshold for the P phase",
)
@click.option(
    "-ts",
    "--threshold-s",
    default=0.75,
    type=float,
    show_default=True,
    help="detection threshold for the S phase",
)
@click.argument("stream_file_names", nargs=-1, type=click.Path(exists=True))
def pick(stream_file_names, weights, output, stride, threshold_p, threshold_s):
    """Detect phases in streams"""
    if not output.exists():
        output.mkdir()
    m = GPDModelRunner(
        weights,
        output_dir=output,
        stride=stride,
        threshold_p=threshold_p,
        threshold_s=threshold_s,
    )
    for stream in stream_file_names:
        m.find_picks(stream)
